@@ -1,12 +1,14 @@
+import os
 import cymysql
 import unittest
 
 class PyMySQLTestCase(unittest.TestCase):
     # Edit this to suit your test environment.
+    test_passwd = os.environ.get("MYSQL_ROOT_PASSWORD", "")
     databases = [
-        {"host":"localhost","user":"root",
-         "passwd":"","db":"test_cymysql", "use_unicode": True},
-        {"host":"localhost","user":"root","passwd":"","db":"test_cymysql2"}]
+        {"host":"localhost", "user":"root",
+         "passwd":test_passwd, "db":"test_cymysql", "use_unicode": True},
+        {"host":"localhost", "user":"root", "passwd":test_passwd, "db":"test_cymysql2"}]
 
     def setUp(self):
         self.connections = []
