@@ -24,16 +24,13 @@ class TestConversion(base.PyMySQLTestCase):
         c.execute("create table test_datatypes (b bit, i int, l bigint, f real, s varchar(32), u varchar(32), bb blob, d date, dt datetime, ts timestamp, td time, t time, st datetime)")
         try:
             # insert values
-            v = (True, -3, 123456789012, 5.7, "hello'\" world", u('Espa\xc3\xb1ol'), b"binary\x00data", datetime.date(1988,2,2), datetime.datetime.now(), datetime.timedelta(5,6), datetime.time(16,32), time.localtime())
+
+            v = (True, -3, 123456789012, 5.7, "hello'\" world", u"Espa\xc3\xb1ol", "binary\x00data".encode(conn.encoding), datetime.date(1988,2,2), datetime.datetime(2014, 5, 15, 7, 45, 57), datetime.timedelta(5,6), datetime.time(16,32), time.localtime())
             c.execute("insert into test_datatypes (b,i,l,f,s,u,bb,d,dt,td,t,st) values (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)", v)
             c.execute("select b,i,l,f,s,u,bb,d,dt,td,t,st from test_datatypes")
             r = c.fetchone()
             self.assertEqual(int2byte(1), r[0])
-            self.assertEqual(v[1:8], r[1:8])
-            # mysql throws away microseconds so we need to check datetimes
-            # specially. additionally times are turned into timedeltas.
-            self.assertEqual(datetime.datetime(*v[8].timetuple()[:6]), r[8])
-            self.assertEqual(v[9], r[9]) # just timedeltas
+            self.assertEqual(v[1:10], r[1:10])
             self.assertEqual(datetime.timedelta(0, 60 * (v[10].hour * 60 + v[10].minute)), r[10])
             self.assertEqual(datetime.datetime(*v[-1][:6]), r[-1])
 
@@ -101,7 +98,7 @@ class TestConversion(base.PyMySQLTestCase):
             data = "cymysql" * 1024
             c.execute("insert into test_big_blob (b) values (%s)", (data,))
             c.execute("select b from test_big_blob")
-            self.assertEqual(data.encode(conn.charset), c.fetchone()[0])
+            self.assertEqual(data.encode(conn.encoding), c.fetchone()[0])
         finally:
             c.execute("drop table test_big_blob")
     
@@ -132,6 +129,16 @@ class TestConversion(base.PyMySQLTestCase):
                           datetime.timedelta(0, 83579, 51000)),
                          c.fetchone())
 
+    def test_callproc(self):
+        conn = self.connections[0]
+        c = conn.cursor()
+        c.execute("drop procedure if exists test_proc")
+        c.execute("create procedure test_proc(IN s varchar(20)) begin select lower(s); end")
+        c.callproc('test_proc', ('Foo', ))
+        r = c.fetchall()
+        self.assertEqual(len(r), 1)
+        self.assertEqual(r[0], (u'foo', ))
+
 
 class TestCursor(base.PyMySQLTestCase):
     # this test case does not work quite right yet, however,
@@ -259,7 +266,20 @@ class TestCursor(base.PyMySQLTestCase):
         except cymysql.ProgrammingError:
             pass
 
-__all__ = ["TestConversion","TestCursor"]
+
+class TestCharset(base.PyMySQLTestCase):
+    def test_charset(self):
+        conn = cymysql.connect(
+            host="localhost", user="root", passwd=self.test_passwd, db="mysql",
+            charset="utf8mb4"
+        )
+        c = conn.cursor()
+        c.execute("select user from user where user='root'")
+        self.assertEqual(c.fetchone()[0], 'root')
+        conn.close()
+
+
+__all__ = ["TestConversion","TestCursor", "TestCharset"]
 
 if __name__ == "__main__":
     import unittest
